package com.coixinera.footprintsDB;

import java.util.ArrayList;

import android.content.ContentResolver;
import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.net.Uri;

import com.coixinera.footprintsProvider.LugaresProvider;
import com.coixinera.footprintscollector.AdaptadorListaLugares;
import com.coixinera.footprintscollector.Lugar;
import com.coixinera.footprintscollector.R;
import com.google.android.gms.maps.model.LatLng;

//Clase DAO que contiene centralizadas todas las llamadas y consultas a 
//la base de datos a travs de metodos. la instancio cada vez que es necesario dentro de la aplicacin
//para hacer operaciones en la base de datos 
public class FootPrints_DAO {

	Uri lugaresUri = LugaresProvider.CONTENT_URI;

	public AdaptadorListaLugares consultarListaLugares(Context context,
			String filtro) {

		String[] projection = new String[] {
				FootPrintsDB_parameters.FootPrintsTable._ID,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD };

		String[] from = new String[] {
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD, };

		int[] to = new int[] { R.id.list_item_nombre,
				R.id.list_item_descripcion };

		ContentResolver cr = context.getContentResolver();

		Cursor cursor;
		String gg = FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE
				+ " LIKE %" + filtro + "%";

		if (filtro == null || filtro.equals("")) {
			cursor = cr.query(lugaresUri, projection, null, null, null);
		} else {
			cursor = cr.query(lugaresUri, projection,
					FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE
							+ " LIKE \"%" + filtro + "%\"", null, null);
		}

		int longitud = cursor.getCount();

		AdaptadorListaLugares adapter = new AdaptadorListaLugares(context,
				cursor, projection, to);

		return adapter;

	}

	public ArrayList<Lugar> consultarMapaLugares(Context context) {

		String[] projection = new String[] {
				FootPrintsDB_parameters.FootPrintsTable._ID,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO };

		ContentResolver cr = context.getContentResolver();
		Cursor cursor = cr.query(lugaresUri, projection, null, null, null);

		ArrayList<Lugar> lugares = new ArrayList<Lugar>();

		if (cursor.moveToFirst()) {
			do {
				Lugar lugar = new Lugar();
				lugar.set_id(cursor.getInt(0));
				lugar.setNombre(cursor.getString(1));
				lugar.setDescripcion(cursor.getString(2));
				lugar.setCoordenadas(new LatLng(cursor.getDouble(3), cursor
						.getDouble(4)));
				lugar.setFoto(Uri.parse(cursor.getString(5)));
				lugares.add(lugar);
			} while (cursor.moveToNext());

		}

		return lugares;

	}

	public Lugar consultarLugar(int id, Context context) {

		String[] projection = new String[] {
				FootPrintsDB_parameters.FootPrintsTable._ID,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO };

		Lugar lugar = new Lugar();

		ContentResolver cr = context.getContentResolver();

		Uri uri = Uri.parse(lugaresUri + "/" + id);

		Cursor cursor = cr.query(uri, projection, null, null, null);

		if (cursor.moveToFirst()) {

			int colId = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_ID);
			int colNombre = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE);
			int colDescripcion = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION);
			int colLatitud = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD);
			int colLongitud = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD);
			int colFoto = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO);

			do {
				lugar.set_id(cursor.getInt(colId));
				lugar.setNombre(cursor.getString(colNombre));
				lugar.setDescripcion(cursor.getString(colDescripcion));
				LatLng coordenadas = new LatLng(cursor.getDouble(colLatitud),
						cursor.getDouble(colLongitud));
				lugar.setCoordenadas(coordenadas);
				lugar.setFoto(Uri.parse(cursor.getString(colFoto)));

			} while (cursor.moveToNext());

		}

		return lugar;

	}

	public void insertarLugar(Lugar lugar, Context context) {

		ContentValues values = new ContentValues();

		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				lugar.getNombre());
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				lugar.getDescripcion());
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				lugar.getCoordenadas().latitude);
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD,
				lugar.getCoordenadas().longitude);
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO, lugar
				.getFoto().toString());

		ContentResolver cr = context.getContentResolver();

		cr.insert(lugaresUri, values);

	}

	public int eliminarLugar(int id, Context context) {

		ContentResolver cr = context.getContentResolver();

		Uri uri = Uri.parse(lugaresUri + "/" + id);
		return cr.delete(uri, null, null);

	}

	public void editarLugar(Context context, int id, Lugar lugar) {

		ContentValues values = new ContentValues();

		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				lugar.getNombre());
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				lugar.getDescripcion());
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				lugar.getCoordenadas().latitude);
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD,
				lugar.getCoordenadas().longitude);
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO, lugar
				.getFoto().toString());

		ContentResolver cr = context.getContentResolver();

		Uri uri = Uri.parse(lugaresUri + "/" + id);

		cr.update(uri, values, null, null);

	}

	public void actualizarPosicionLugar(Context context,
			LatLng coordenadasNuevas, int idLugar) {

		String[] projection = new String[] {
				FootPrintsDB_parameters.FootPrintsTable._ID,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO };

		Lugar lugar = new Lugar();

		ContentResolver cr = context.getContentResolver();

		Uri uri = Uri.parse(lugaresUri + "/" + idLugar);

		Cursor cursor = cr.query(uri, projection, null, null, null);

		if (cursor.moveToFirst()) {

			int colId = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_ID);
			int colNombre = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE);
			int colDescripcion = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION);
			int colLatitud = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD);
			int colLongitud = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD);
			int colFoto = cursor
					.getColumnIndex(FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO);

			do {
				lugar.set_id(cursor.getInt(colId));
				lugar.setNombre(cursor.getString(colNombre));
				lugar.setDescripcion(cursor.getString(colDescripcion));
				LatLng coordenadas = new LatLng(cursor.getDouble(colLatitud),
						cursor.getDouble(colLongitud));
				lugar.setCoordenadas(coordenadas);
				lugar.setFoto(Uri.parse(cursor.getString(colFoto)));

			} while (cursor.moveToNext());

		}

		ContentValues values = new ContentValues();

		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				lugar.getNombre());
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				lugar.getDescripcion());
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				coordenadasNuevas.latitude);
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD,
				coordenadasNuevas.longitude);
		values.put(FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO, lugar
				.getFoto().toString());

		cr = context.getContentResolver();

		uri = Uri.parse(lugaresUri + "/" + idLugar);

		cr.update(uri, values, null, null);

	}

	public LatLng ConsultarUltimoLugar(Context context) {

		String[] projection = new String[] {
				FootPrintsDB_parameters.FootPrintsTable._ID,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD,
				FootPrintsDB_parameters.FootPrintsTable.CAMPO_FOTO };

		ContentResolver cr = context.getContentResolver();
		Cursor cursor = cr.query(lugaresUri, projection, null, null, null);

		ArrayList<Lugar> lugares = new ArrayList<Lugar>();
		int idMayor = 0;
		Double latitud = 0.0;
		Double longitud = 0.0;
		if (cursor.moveToFirst()) {
			do {
				if (cursor.getInt(0) > idMayor) {
					latitud = cursor.getDouble(3);
					longitud = cursor.getDouble(4);
					idMayor = cursor.getInt(0);
				}

			} while (cursor.moveToNext());

		}
		LatLng coordenadas = new LatLng(latitud, longitud);

		return coordenadas;
	}

}
