package com.coixinera.footprintsProvider;

import android.content.ContentProvider;
import android.content.ContentUris;
import android.content.ContentValues;
import android.content.UriMatcher;
import android.database.Cursor;
import android.database.sqlite.SQLiteDatabase;
import android.net.Uri;

import com.coixinera.footprintsDB.FootPrintsDB_parameters;
import com.coixinera.footprintsDB.FootPrintsSQLHelper;

public class LugaresProvider extends ContentProvider {

	// Definicin del CONTENT_URI
	private static final String uri = "content://com.coixinera.footprintsProvider/footprints";
	public static final Uri CONTENT_URI = Uri.parse(uri);

	// Base de datos
	private FootPrintsSQLHelper dbFootprints;

	// parametros para configurar el UriMatcher
	private static final int LUGARES = 1;
	private static final int LUGARES_ID = 2;
	private static final UriMatcher uriMatcher;

	// inicializacin UriMatcher
	static {
		uriMatcher = new UriMatcher(UriMatcher.NO_MATCH);
		uriMatcher.addURI("com.coixinera.footprintsProvider", "footprints",
				LUGARES);
		uriMatcher.addURI("com.coixinera.footprintsProvider", "footprints/#",
				LUGARES_ID);
	}

	@Override
	public int delete(Uri uri, String selection, String[] selectionArgs) {

		int cont;
		String where = selection;

		if (uriMatcher.match(uri) == LUGARES_ID) {
			where = "_id=" + uri.getLastPathSegment();
		}

		SQLiteDatabase db = dbFootprints.getWritableDatabase();

		cont = db.delete(FootPrintsDB_parameters.FootPrintsTable.NOMBRE_TABLA, where,
				selectionArgs);

		return cont;

	}

	@Override
	public String getType(Uri uri) {

		int match = uriMatcher.match(uri);

		switch (match) {
		case LUGARES:
			return "vnd.android.cursor.dir/vnd.footprints.lugares";
		case LUGARES_ID:
			return "vnd.android.cursor.item/vnd.footprints.lugares";
		default:
			return null;
		}

	}

	@Override
	public Uri insert(Uri uri, ContentValues values) {

		long regId;
		SQLiteDatabase db = dbFootprints.getWritableDatabase();

		regId = db.insert(FootPrintsDB_parameters.FootPrintsTable.NOMBRE_TABLA, null,
				values);

		Uri newUri = ContentUris.withAppendedId(CONTENT_URI, regId);

		return newUri;
	}

	@Override
	public boolean onCreate() {

		dbFootprints = new FootPrintsSQLHelper(getContext());

		return true;
	}

	@Override
	public Cursor query(Uri uri, String[] projection, String selection,
			String[] selectionArgs, String sortOrder) {

		String where = selection;

		if (uriMatcher.match(uri) == LUGARES_ID) {
			where = "_id=" + uri.getLastPathSegment();
		}

		SQLiteDatabase db = dbFootprints.getWritableDatabase();

		Cursor c = db.query(FootPrintsDB_parameters.FootPrintsTable.NOMBRE_TABLA,
				projection, where, selectionArgs, null, null, sortOrder);

		return c;
	}

	@Override
	public int update(Uri uri, ContentValues values, String selection,
			String[] selectionArgs) {

		int cont;
		String where = selection;

		if (uriMatcher.match(uri) == LUGARES_ID) {
			where = "_id=" + uri.getLastPathSegment();
		}

		SQLiteDatabase db = dbFootprints.getWritableDatabase();

		cont = db.update(FootPrintsDB_parameters.FootPrintsTable.NOMBRE_TABLA, values,
				where, selectionArgs);

		return cont;
	}

}
