package com.coixinera.footprintscollector;

import android.app.Activity;
import android.content.Context;
import android.content.Intent;
import android.database.Cursor;
import android.location.Criteria;
import android.location.Location;
import android.location.LocationListener;
import android.location.LocationManager;
import android.net.Uri;
import android.os.Bundle;
import android.support.v4.widget.SimpleCursorAdapter;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;
import android.widget.ImageButton;
import android.widget.LinearLayout;
import android.widget.TextView;
import android.widget.Toast;

import com.coixinera.footprintsDB.FootPrintsDB_parameters;

//Clase generada para tener una adaptacin personalizada de un SimpleCursorAdapter y 
//asi poder manejar tanto la informacin que se muestra como el diseo de la misma cuando se utilize junto
//con un ListView. Instacio esta clase en lugar del SimpleCursorAdapter

public class AdaptadorListaLugares extends SimpleCursorAdapter {

	Activity context;

	private Context mContext;
	private Context appContext;
	private int layout;
	private Cursor lugares;
	private final LayoutInflater inflater;

	LocationManager locManager;
	LocationListener locListener;
	Location loc;
	boolean providerEnabled = false;
	double latitudLugar;
	double longitudLugar;

	// Cargamos y pasamos el Layout que hemos creado para cada uno de los Items
	// de la lista
	public AdaptadorListaLugares(Context context, Cursor lugares,
			String[] from, int[] to) {
		super(context, R.layout.listitem_listalugares, lugares, from, to);

		this.inflater = LayoutInflater.from(context);
		this.mContext = context;
		layout = R.layout.listitem_listalugares;
		this.context = (Activity) context;
		this.lugares = lugares;

	}

	@Override
	public void bindView(View view, final Context context, Cursor cursor) {

		super.bindView(view, context, cursor);

		// asignamos los elementos del layout personalizado con los elementos
		// del cursor
		// para cada Item

		TextView listaItemNombre = (TextView) view
				.findViewById(R.id.list_item_nombre);
		TextView listaItemDescripcion = (TextView) view
				.findViewById(R.id.list_item_descripcion);

		TextView listaItemLatitud = (TextView) view
				.findViewById(R.id.list_item_latitud);

		TextView listaItemLongitud = (TextView) view
				.findViewById(R.id.list_item_longitud);

		ImageButton listaItemRutaCoche = (ImageButton) view
				.findViewById(R.id.btn_boton_ruta);

		int nombre_index = cursor
				.getColumnIndexOrThrow(FootPrintsDB_parameters.FootPrintsTable.CAMPO_NOMBRE);
		int descripcion_index = cursor
				.getColumnIndexOrThrow(FootPrintsDB_parameters.FootPrintsTable.CAMPO_DESCRIPCION);

		// latitud y longitud son dos campos que no se ven en la vista pero que
		// cargo para poder recuperarlos en caso de que el usuario pida la ruta
		// en coche a esas coordenadas
		int latitud_index = cursor
				.getColumnIndexOrThrow(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LATITUD);
		int longitud_index = cursor
				.getColumnIndexOrThrow(FootPrintsDB_parameters.FootPrintsTable.CAMPO_LONGITUD);

		String nombre = cursor.getString(nombre_index);
		listaItemNombre.setText(nombre);

		String descripcion = cursor.getString(descripcion_index);
		listaItemDescripcion.setText(descripcion);

		String latitud = cursor.getString(latitud_index);
		listaItemLatitud.setText(latitud);

		String longitud = cursor.getString(longitud_index);
		listaItemLongitud.setText(longitud);

		// Cargo un location manager que junto con un listener me permite
		// localizar la posicin actual. Lo utilizare para la la opcion de click
		// en ruta en coche
		locManager = (LocationManager) view.getContext().getSystemService(
				view.getContext().LOCATION_SERVICE);

		Criteria req = new Criteria();
		req.setAccuracy(Criteria.NO_REQUIREMENT);
		String gpsProvider = locManager.getBestProvider(req, false);

		loc = locManager.getLastKnownLocation(gpsProvider);
		providerEnabled = locManager.isProviderEnabled(gpsProvider);
		locListener = new LocationListener() {

			@Override
			public void onStatusChanged(String provider, int status,
					Bundle extras) {

			}

			@Override
			public void onProviderEnabled(String provider) {

				providerEnabled = true;
			}

			@Override
			public void onProviderDisabled(String provider) {

				providerEnabled = false;
			}

			@Override
			public void onLocationChanged(Location location) {
				loc = location;

			}
		};

		locManager.requestLocationUpdates(gpsProvider, 5000, 0, locListener);

		listaItemRutaCoche
				.setOnClickListener(new ImageButton.OnClickListener() {
					// al hacer click en el boton ruta, se cogen las coordenadas
					// del lugar escogido (campos ocultos del item) y junto con
					// la posicin actual (location manager) se
					// mandan a Google Navigation para que traze una ruta en
					// coche entre los dos puntos
					@Override
					public void onClick(View v) {

						View view = (LinearLayout) v.getParent();
						TextView listaItemLatitud = (TextView) view
								.findViewById(R.id.list_item_latitud);

						TextView listaItemLongitud = (TextView) view
								.findViewById(R.id.list_item_longitud);

						latitudLugar = Double.valueOf(listaItemLatitud
								.getText().toString());
						longitudLugar = Double.valueOf(listaItemLongitud
								.getText().toString());

						if (providerEnabled && loc != null) {

							String uri = "http://maps.google.com/maps?saddr="
									+ loc.getLatitude() + ","
									+ loc.getLongitude() + "&daddr="
									+ latitudLugar + "," + longitudLugar;
							Intent intent = new Intent(
									android.content.Intent.ACTION_VIEW, Uri
											.parse(uri));
							intent.setClassName("com.google.android.apps.maps",
									"com.google.android.maps.MapsActivity");
							context.startActivity(intent);

						} else {

							Toast.makeText(v.getContext(),
									R.string.error_posicion_no_encontrada,
									Toast.LENGTH_SHORT).show();

						}

					}
				});

	}

	@Override
	public View newView(Context context, Cursor cursor, ViewGroup parent) {

		return inflater.inflate(layout, null);
	}

}
