package com.coixinera.footprintscollector;

import java.io.FileNotFoundException;
import java.io.IOException;
import java.io.InputStream;

import android.content.Context;
import android.graphics.Bitmap;
import android.graphics.Bitmap.Config;
import android.graphics.BitmapFactory;
import android.graphics.Canvas;
import android.graphics.Paint;
import android.graphics.PorterDuff.Mode;
import android.graphics.PorterDuffXfermode;
import android.graphics.Rect;
import android.graphics.RectF;
import android.net.Uri;

//Clase auxiliar que contiene un mtodo que genera un Bitmap a travs de una uri y un contexto
//y lo devuelve al demandante. He externalizado este mtodo por que lo utilizo en varios sitios de la
//aplicacin y lo he hecho estatico para no tener siquiera que crear una instancia de la clase para utilizar
//este mtodo.

public class BitmapGetter {

	public static Bitmap getBitmap(Uri uri, Context context) {

		int height;
		int width;
		Bitmap bitmap = null;

		BitmapFactory.Options options = new BitmapFactory.Options();
		options.inSampleSize = 2;

		InputStream is = null;
		try {
			is = context.getContentResolver().openInputStream(uri);
			bitmap = BitmapFactory.decodeStream(is, null, options);
			is.close();

		} catch (FileNotFoundException e) {
			e.printStackTrace();
		} catch (IOException e) {
			// TODO Auto-generated catch block
			e.printStackTrace();
		}

		height = bitmap.getHeight();
		width = bitmap.getWidth();

		Bitmap output = Bitmap.createBitmap(width, height, Config.ARGB_8888);
		Canvas canvas = new Canvas(output);

		final int color = 0xff424242;
		final Paint paint = new Paint();
		final Rect rect = new Rect(0, 0, width, height);
		final RectF rectF = new RectF(rect);
		final float roundPx = 70;

		paint.setAntiAlias(true);
		canvas.drawARGB(0, 0, 0, 0);
		paint.setColor(color);
		canvas.drawRoundRect(rectF, roundPx, roundPx, paint);

		paint.setXfermode(new PorterDuffXfermode(Mode.SRC_IN));
		canvas.drawBitmap(bitmap, rect, rect, paint);

		return output;

	}

}
